@@ -25,7 +25,7 @@ def provide_jpype_stubs(stub_tmpdir: str):
     jpype_dir = os.path.dirname(jp.__file__)
     jpype_dest = pathlib.Path(stub_tmpdir) / os.path.basename(jpype_dir)
     shutil.copytree(jpype_dir, jpype_dest)
-    (jpype_dest / 'py.typed').touch()
+    (jpype_dest / 'py.typed').write_text('partial\n')
 
 
 @pytest.fixture(scope="session", autouse=True)
@@ -43,9 +43,21 @@ def setup_mypy_for_data_driven_tests(stub_tmpdir: str):
 
 def test_generate_stubs(stub_tmpdir):
     import java.util  # noqa
-    stubgenj.generateJavaStubs([java.util], useStubsSuffix=True, outputDir=stub_tmpdir)
+    stubgenj.generateJavaStubs(
+        [java.util],
+        useStubsSuffix=True, outputDir=stub_tmpdir,
+    )
 
 
 @pytest.mark.trylast
 class StubTestSuite(mypy.test.testcheck.TypeCheckSuite):
-    files = ['arraylist.test', 'hashmap.test', 'enummap.test', 'callbacks.test']
+    files = [
+        'arraylist.test',
+        'callbacks.test',
+        'enummap.test',
+        'forward_declaration.test',
+        'hashmap.test',
+        'jpype_jpackage.test',
+        'mangled_python_keywords.test',
+        'varargs.test',
+    ]
